@@ -82,36 +82,41 @@ def minify(in_file, out_file = None, verbose=False):
 
     new_size = os.path.getsize(out_file)
 
+    #avoid division by zero
+    if not new_size:
+        console.fail('Compression fail')
+
     
     console.info('  ~ Original: %.2f kB' % (org_size / 1024.0))
     console.info('  ~ Compressed: %.2f kB' % (new_size / 1024.0))
     console.confirm('  %s ( Reduction : %.1f%% )' % (out_file, (float(org_size - new_size) / org_size * 100)))
 
 
-def jslint(files, fix = False, strict = False, nojsdoc = False, relax = False):
+def jslint(files, fix = False, relax = False):
     files = FileList.check(files)
 
     options = []
     command = ""
 
-    if strict == True:
-        options.append('--strict')
-    
-    if nojsdoc == True:
-        options.append('--nojsdoc')
-    
-    
+    options.append('--jslint_error=optional_type_marker')
+    options.append('--jslint_error=blank_lines_at_top_level')
+    options.append('--jslint_error=indentation')
+    options.append('--custom_jsdoc_tags=version,ignore,returns,example,function,requires,name, \
+                                        namespace,property,static,constant,default,location, \
+                                        copyright,memberOf,lends,fileOverview')
 
 
     if fix == True:
+        header = "Fix JS lint"
         command = "fixjsstyle %s %s "  % (  ' '.join(options) , ' '.join(files))
     else:
+        header = "JS lint"
         command = "gjslint %s %s "  % (  ' '.join(options) , ' '.join(files))
     
     if relax == True:
-        command += ' | grep -v "Line too long" | grep -v "Invalid JsDoc tag"'
+        command += ' | grep -v "Line too long"'
     
-    sh(command)
+    sh(command, header = "%s (%s files)" % (header, len(files)) )
 
 def jsdoc(files, folder, template = None):
     files = FileList.check(files)
